# Generated by Django 6.0 on 2026-01-14 22:08

import _socket
import django.db.models.deletion
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_pharmacy.models.stock.confirmation_at_location_item
import edc_sites.managers
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0091_alter_allocation_revision_alter_assignment_revision_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalConfirmationAtSiteItem",
            new_name="HistoricalConfirmationAtLocationItem",
        ),
        migrations.RenameModel(
            old_name="ConfirmationAtSiteItem",
            new_name="ConfirmationAtLocationItem",
        ),
        migrations.RenameModel(
            old_name="HistoricalConfirmationAtSite",
            new_name="HistoricalConfirmationAtLocation",
        ),
        migrations.RenameModel(
            old_name="ConfirmationAtSite",
            new_name="ConfirmationAtLocation",
        ),
    ]
