PROTOCOL_VIOLATION = "PROTOCOL_VIOLATION"
PROTOCOL_VIOLATION_VIEW = "PROTOCOL_VIOLATION_VIEW"
PROTOCOL_INCIDENT = "PROTOCOL_INCIDENT"
PROTOCOL_INCIDENT_VIEW = "PROTOCOL_INCIDENT_VIEW"


protocol_violation_codenames = (
    "edc_protocol_incident.add_protocoldeviationviolation",
    "edc_protocol_incident.change_protocoldeviationviolation",
    "edc_protocol_incident.delete_protocoldeviationviolation",
    "edc_protocol_incident.view_protocoldeviationviolation",
)

protocol_violation_view_codenames = ("edc_protocol_incident.view_protocoldeviationviolation",)


protocol_incident_codenames = (
    "edc_protocol_incident.add_protocolincident",
    "edc_protocol_incident.change_protocolincident",
    "edc_protocol_incident.delete_protocolincident",
    "edc_protocol_incident.view_protocolincident",
)

protocol_incident_view_codenames = ("edc_protocol_incident.view_protocolincident",)
