# Generated by Django 6.0 on 2025-02-27 08:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0054_historicalreceiveitem_task_id_receiveitem_task_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalreceiveitem",
            name="comment",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalreceiveitem",
            name="reference",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name="receiveitem",
            name="comment",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="receiveitem",
            name="reference",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
    ]
