# Generated by Django 3.0.4 on 2020-05-11 22:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_export", "0004_auto_20190305_0123"),
    ]

    operations = [
        migrations.CreateModel(
            name="ExportData",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
            ],
            options={
                "permissions": (("display_export_admin_action", "Display export action"),),
            },
        ),
        migrations.CreateModel(
            name="ImportData",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
            ],
            options={
                "permissions": (("show_import_admin_action", "Show import action"),),
            },
        ),
    ]
