# Generated by Django 6.0 on 2025-03-14 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0065_allocationproxy"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstock",
            name="stored_at_site",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="stock",
            name="stored_at_site",
            field=models.BooleanField(default=False),
        ),
    ]
