# Generated by Django 5.1.2 on 2024-11-18 01:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0039_remove_dispense_registered_subject_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstock",
            name="dispensed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="stock",
            name="dispensed",
            field=models.BooleanField(default=False),
        ),
    ]
