# Generated by Django 5.2.10 on 2026-01-25 22:46

import django.db.models.manager
import edc_sites.managers
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0130_historicalstocktransfer_cancel_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="StorageBinItemProxy",
            fields=[],
            options={
                "verbose_name": "Storage bin item",
                "verbose_name_plural": "Storage bin items",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("edc_pharmacy.storagebinitem",),
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="StorageBinProxy",
            fields=[],
            options={
                "verbose_name": "Storage bin",
                "verbose_name_plural": "Storage bins",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("edc_pharmacy.storagebin",),
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]
