# Generated by Django 5.1.2 on 2024-11-20 00:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0047_historicalstockrequest_cancel_stockrequest_cancel_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalorderitem",
            name="unit_qty_ordered",
            field=models.DecimalField(decimal_places=2, max_digits=20, null=True),
        ),
        migrations.AddField(
            model_name="orderitem",
            name="unit_qty_ordered",
            field=models.DecimalField(decimal_places=2, max_digits=20, null=True),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="unit qty ordered less unit qty received",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalstockrequest",
            name="cancel",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=6,
                null=True,
                verbose_name="To cancel this request, type the word 'CANCEL' here and save the form:",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="unit qty ordered less unit qty received",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="stockrequest",
            name="cancel",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=6,
                null=True,
                verbose_name="To cancel this request, type the word 'CANCEL' here and save the form:",
            ),
        ),
    ]
