# Generated by Django 3.2.13 on 2022-09-13 21:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_registration", "0024_auto_20220704_1841"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalregisteredsubject",
            name="ethnicity",
            field=models.CharField(blank=True, max_length=15, null=True),
        ),
        migrations.AddField(
            model_name="registeredsubject",
            name="ethnicity",
            field=models.CharField(blank=True, max_length=15, null=True),
        ),
    ]
