# Generated by Django 6.0 on 2026-01-13 17:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0094_auto_20260113_0357"),
    ]

    operations = []
