# Generated by Django 5.2.6 on 2025-09-17 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_reportable", "0006_alter_gradingdata_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="gradingdata",
            name="age_phrase",
            field=models.CharField(
                default="", help_text="calculated in save()", max_length=25
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="age_upper_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="description",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="lln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="lower_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="phrase",
            field=models.CharField(
                default="",
                help_text="calculated by the formula instance",
                max_length=50,
                verbose_name="Value phrase",
            ),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="reference_group",
            field=models.CharField(default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="uln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="gradingdata",
            name="upper_operator",
            field=models.CharField(default="", max_length=2),
        ),
        migrations.AlterField(
            model_name="gradingexception",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="gradingexception",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="gradingexception",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="gradingexception",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="age_phrase",
            field=models.CharField(
                default="", help_text="calculated in save()", max_length=25
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="age_upper_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="description",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="lln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="lower_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="phrase",
            field=models.CharField(
                default="",
                help_text="calculated by the formula instance",
                max_length=50,
                verbose_name="Value phrase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="reference_group",
            field=models.CharField(default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="uln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalgradingdata",
            name="upper_operator",
            field=models.CharField(default="", max_length=2),
        ),
        migrations.AlterField(
            model_name="historicalmolecularweight",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmolecularweight",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmolecularweight",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmolecularweight",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="age_phrase",
            field=models.CharField(
                default="", help_text="calculated in save()", max_length=25
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="age_upper_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="description",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="lln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="lower_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="phrase",
            field=models.CharField(
                default="",
                help_text="calculated by the formula instance",
                max_length=50,
                verbose_name="Value phrase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="reference_group",
            field=models.CharField(default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="uln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalnormaldata",
            name="upper_operator",
            field=models.CharField(default="", max_length=2),
        ),
        migrations.AlterField(
            model_name="molecularweight",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="molecularweight",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="molecularweight",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="molecularweight",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="age_phrase",
            field=models.CharField(
                default="", help_text="calculated in save()", max_length=25
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="age_upper_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="description",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="lln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="lower_operator",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="phrase",
            field=models.CharField(
                default="",
                help_text="calculated by the formula instance",
                max_length=50,
                verbose_name="Value phrase",
            ),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="reference_group",
            field=models.CharField(default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="uln",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="normaldata",
            name="upper_operator",
            field=models.CharField(default="", max_length=2),
        ),
        migrations.AlterField(
            model_name="referencerangecollection",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="referencerangecollection",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="referencerangecollection",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="referencerangecollection",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
    ]
