# Generated by Django 6.0 on 2026-01-13 00:57

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0093_alter_confirmationatlocation_options_and_more"),
    ]

    operations = []
