# Generated by Django 5.2.8 on 2025-11-20 22:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_metadata",
            "0033_remove_crfmetadata_edc_metadat_site_id_d3b213_idx_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="crfmetadata",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": (
                    "subject_identifier",
                    "visit_code",
                    "visit_code_sequence",
                    "show_order",
                ),
                "verbose_name": "Crf collection status",
                "verbose_name_plural": "Crf collection status",
            },
        ),
    ]
