# Generated by Django 5.2.10 on 2026-01-24 15:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0108_alter_container_qty_suggested_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="container",
            old_name="qty_decimal_places",
            new_name="qty_suggested_places",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty_decimal_places",
            new_name="qty_suggested_places",
        ),
    ]
