# Generated by Django 4.2.3 on 2023-08-02 23:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_protocol_incident",
            "0018_alter_protocoldeviationviolation_options_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="actionsrequired",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="protocolincidents",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="protocolviolations",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
    ]
