BLOOD_RESULTS_EGFR_ACTION = "abnormal-blood-results-egfr"
BLOOD_RESULTS_FBC_ACTION = "abnormal-blood-results-fbc"
BLOOD_RESULTS_GLU_ACTION = "abnormal-blood-results-glu"
BLOOD_RESULTS_HBA1C_ACTION = "abnormal-blood-results-hba1c"
BLOOD_RESULTS_INSULIN_ACTION = "abnormal-blood-results-ins"
BLOOD_RESULTS_LFT_ACTION = "abnormal-blood-results-lft"
BLOOD_RESULTS_LIPIDS_ACTION = "abnormal-blood-results-lipid"
BLOOD_RESULTS_RFT_ACTION = "abnormal-blood-results-rft"
URINALYSIS_ACTION = "abnormal-urinalysis"
