OFFSTUDY = "OFFSTUDY"
OFFSTUDY_VIEW = "OFFSTUDY_VIEW"
OFFSTUDY_SUPER = "OFFSTUDY_SUPER"
codenames = [
    "edc_offstudy.add_subjectoffstudy",
    "edc_offstudy.change_subjectoffstudy",
    "edc_offstudy.delete_subjectoffstudy",
    "edc_offstudy.view_historicalsubjectoffstudy",
    "edc_offstudy.view_subjectoffstudy",
]
