# Generated by Django 5.2.10 on 2026-01-25 01:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0121_confirmation_code_historicalconfirmation_code_and_more"),
    ]

    operations = []
