# Generated by Django 5.1 on 2024-08-15 22:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0015_alter_note_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="note",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                    "viewallsites",
                ),
                "verbose_name": "Note",
                "verbose_name_plural": "Notes",
            },
        ),
        migrations.AlterModelOptions(
            name="qareportlog",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "verbose_name": "QA Report Log",
                "verbose_name_plural": "QA Report Logs",
            },
        ),
    ]
