# Generated by Django 4.2.3 on 2023-07-20 03:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_locator", "0032_alter_subjectlocator_managers"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="subjectlocator",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Subject Locator",
                "verbose_name_plural": "Subject Locators",
            },
        ),
    ]
