# Generated by Django 5.2.10 on 2026-01-25 05:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0128_auto_20260125_0741"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrepackrequest",
            name="override_container_unit_qty",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="repackrequest",
            name="override_container_unit_qty",
            field=models.BooleanField(default=False),
        ),
    ]
