# Generated by Django 4.1.2 on 2023-02-28 00:40

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0026_auto_20220826_0258"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dataquery",
            name="dm_user",
            field=models.ForeignKey(
                blank=True,
                help_text="select a name from the list",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_data_manager.datamanageruser",
                verbose_name="DM resolved by",
            ),
        ),
    ]
