# Generated by Django 5.2.10 on 2026-01-24 15:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0107_remove_container_qty_remove_historicalcontainer_qty_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="container",
            name="qty_suggested",
            field=models.DecimalField(
                decimal_places=2,
                help_text="May be adjusted at receiving",
                max_digits=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalcontainer",
            name="qty_suggested",
            field=models.DecimalField(
                decimal_places=2,
                help_text="May be adjusted at receiving",
                max_digits=10,
                null=True,
            ),
        ),
    ]
