# Generated by Django 4.2.7 on 2023-12-05 03:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_lab", "0030_remove_aliquot_edc_lab_ali_modifie_49b6da_idx_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="box",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Box",
                "verbose_name_plural": "Boxes",
            },
        ),
        migrations.AlterModelOptions(
            name="boxitem",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Box Item",
            },
        ),
        migrations.AlterModelOptions(
            name="boxtype",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Box Type",
            },
        ),
        migrations.AlterModelOptions(
            name="manifest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Manifest",
            },
        ),
        migrations.AlterModelOptions(
            name="manifestitem",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Manifest Item",
            },
        ),
        migrations.AlterModelOptions(
            name="shipper",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Shipper",
            },
        ),
        migrations.AlterUniqueTogether(
            name="boxitem",
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name="manifestitem",
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name="panel",
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name="boxitem",
            constraint=models.UniqueConstraint(
                fields=("box", "position"), name="edc_lab_boxitem_box_pos_uniq"
            ),
        ),
        migrations.AddConstraint(
            model_name="boxitem",
            constraint=models.UniqueConstraint(
                fields=("box", "identifier"), name="edc_lab_boxitem_box_ide_uniq"
            ),
        ),
        migrations.AddConstraint(
            model_name="manifestitem",
            constraint=models.UniqueConstraint(
                fields=("manifest", "identifier"),
                name="edc_lab_manifestitem_manifest_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="panel",
            constraint=models.UniqueConstraint(
                fields=("name", "lab_profile_name"), name="edc_lab_panel_name_uniq"
            ),
        ),
    ]
