# Generated by Django 4.2.7 on 2023-12-03 00:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_lab", "0028_alter_aliquot_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="aliquot",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Aliquot",
            },
        ),
        migrations.AlterModelOptions(
            name="box",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("-box_datetime",),
                "verbose_name": "Box",
                "verbose_name_plural": "Boxes",
            },
        ),
        migrations.AlterModelOptions(
            name="boxitem",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("position",),
                "verbose_name": "Box Item",
            },
        ),
        migrations.AlterModelOptions(
            name="boxtype",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("name",),
                "verbose_name": "Box Type",
            },
        ),
        migrations.AlterModelOptions(
            name="consignee",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("name",),
                "verbose_name": "Consignee",
            },
        ),
        migrations.AlterModelOptions(
            name="manifest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("-manifest_identifier",),
                "verbose_name": "Manifest",
            },
        ),
        migrations.AlterModelOptions(
            name="manifestitem",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("created",),
                "verbose_name": "Manifest Item",
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Order",
            },
        ),
        migrations.AlterModelOptions(
            name="panel",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Panel",
                "verbose_name_plural": "Panels",
            },
        ),
        migrations.AlterModelOptions(
            name="result",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Result",
            },
        ),
        migrations.AlterModelOptions(
            name="resultitem",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Result Item",
            },
        ),
        migrations.AlterModelOptions(
            name="shipper",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ("name",),
                "verbose_name": "Shipper",
            },
        ),
        migrations.AddField(
            model_name="aliquot",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="aliquot",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="box",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="box",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="boxitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="boxitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="boxtype",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="boxtype",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="consignee",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="consignee",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalaliquot",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalaliquot",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbox",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbox",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalboxitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalboxitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalconsignee",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalconsignee",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalmanifest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalmanifest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalorder",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalorder",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalresult",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalresult",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalresultitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalresultitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalshipper",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalshipper",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="manifest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="manifest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="manifestitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="manifestitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="order",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="order",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="panel",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="panel",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="result",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="result",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="resultitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="resultitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="shipper",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="shipper",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddIndex(
            model_name="aliquot",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_ali_modifie_49b6da_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aliquot",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_ali_user_mo_5b1f7d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="box",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_box_modifie_af5133_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="box",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_box_user_mo_2bc680_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="boxitem",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_box_modifie_6a2a97_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="boxitem",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_box_user_mo_63be01_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="boxtype",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_box_modifie_eb0207_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="boxtype",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_box_user_mo_b65019_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="consignee",
            index=models.Index(fields=["name"], name="edc_lab_con_name_2de87e_idx"),
        ),
        migrations.AddIndex(
            model_name="manifest",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_man_modifie_aae866_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="manifest",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_man_user_mo_14c069_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="manifestitem",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_man_modifie_113dc0_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="manifestitem",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_man_user_mo_198958_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="order",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_ord_modifie_33b427_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="order",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_ord_user_mo_990f68_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="panel",
            index=models.Index(
                fields=["lab_profile_name", "name"],
                name="edc_lab_pan_lab_pro_2a0c6d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="result",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_res_modifie_edced5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="result",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_res_user_mo_49e9bc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="resultitem",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_res_modifie_d7258d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="resultitem",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_res_user_mo_437ddc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="shipper",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_lab_shi_modifie_822b3b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="shipper",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_lab_shi_user_mo_2a93c7_idx",
            ),
        ),
    ]
