# Generated by Django 5.2.10 on 2026-01-24 20:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0117_alter_historicalorderitem_container_unit_qty_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="container",
            old_name="max_per_subject",
            new_name="max_items_per_subject",
        ),
        migrations.RenameField(
            model_name="container",
            old_name="qty_default",
            new_name="unit_qty_default",
        ),
        migrations.RenameField(
            model_name="container",
            old_name="qty_places",
            new_name="unit_qty_places",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="max_per_subject",
            new_name="max_items_per_subject",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty_default",
            new_name="unit_qty_default",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty_places",
            new_name="unit_qty_places",
        ),
        migrations.RemoveField(
            model_name="container",
            name="qty_may_be_adjusted_from_default",
        ),
        migrations.RemoveField(
            model_name="historicalcontainer",
            name="qty_may_be_adjusted_from_default",
        ),
        migrations.AddField(
            model_name="container",
            name="unit_qty_max",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Maximum unit capacity of container",
                max_digits=10,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalcontainer",
            name="unit_qty_max",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Maximum unit capacity of container",
                max_digits=10,
                null=True,
            ),
        ),
    ]
