# Generated by Django 5.2.3 on 2025-07-09 03:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0086_auto_20250708_2337"),
    ]

    operations = [
        migrations.AlterField(
            model_name="storagebinitem",
            name="stock",
            field=models.OneToOneField(
                limit_choices_to={
                    "confirmationatsiteitem__isnull": False,
                    "dispenseitem__isnull": True,
                },
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.stock",
            ),
        ),
    ]
