# Generated by Django 5.2.10 on 2026-01-25 01:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0120_auto_20260125_0103"),
    ]

    operations = [
        migrations.AddField(
            model_name="confirmation",
            name="code",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                max_length=15,
                verbose_name="Stock code",
            ),
        ),
        migrations.AddField(
            model_name="historicalconfirmation",
            name="code",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                max_length=15,
                verbose_name="Stock code",
            ),
        ),
        migrations.AlterField(
            model_name="container",
            name="display_name",
            field=models.CharField(default="", max_length=100, unique=True),
        ),
        migrations.AlterField(
            model_name="container",
            name="name",
            field=models.CharField(max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalcontainer",
            name="display_name",
            field=models.CharField(db_index=True, default="", max_length=100),
        ),
        migrations.AlterField(
            model_name="historicalcontainer",
            name="name",
            field=models.CharField(db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="container_unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=10,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="reference",
            field=models.CharField(default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="unit_qty_received",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280. Quantiy will recalculate after save.",
                max_digits=10,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="container_unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=10,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="reference",
            field=models.CharField(default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="unit_qty_received",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280. Quantiy will recalculate after save.",
                max_digits=10,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
    ]
