from edc_navbar import Navbar, NavbarItem, site_navbars

label = Navbar(name="edc_label")

label.register(
    NavbarItem(
        name="label",
        label="Label",
        fa_icon="fa-film",
        url_with_namespace="edc_label:home_url",
        codename="edc_navbar.nav_label",
    )
)

site_navbars.register(label)
