from clinicedc_constants import OTHER

list_data = {
    "edc_transfer.transferreasons": [
        ("moved", "Moved away from the area"),
        ("unhappy_with_care", "Was unhappy with the care they are receiving"),
        ("need_specialized_treatment", "Needed more specialist treatment"),
        ("drug_supply", "Due to drug supply "),
        ("stigma", "Concerned about stigma"),
        (OTHER, "Other reason (specify below)"),
    ],
}
