# Generated by Django 5.2.3 on 2025-07-02 21:13

from decimal import Decimal

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0077_historicalstockadjustment_adjustment_datetime_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstock",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Difference of qty_in and qty_out",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="qty_in",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Container qty, e.g. 1 bucket, 1 bottle, etc",
                max_digits=20,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="qty_out",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Container qty, e.g. 1 bucket, 1 bottle, etc",
                max_digits=20,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="unit_qty_in",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Number of units in this container, e.g. 128 tablets. See post-save signal",
                max_digits=20,
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="unit_qty_out",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Number of units from this container, e.g. 128 tablets",
                max_digits=20,
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Difference of qty_in and qty_out",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="qty_in",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Container qty, e.g. 1 bucket, 1 bottle, etc",
                max_digits=20,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="qty_out",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Container qty, e.g. 1 bucket, 1 bottle, etc",
                max_digits=20,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="unit_qty_in",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Number of units in this container, e.g. 128 tablets. See post-save signal",
                max_digits=20,
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="unit_qty_out",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0"),
                help_text="Number of units from this container, e.g. 128 tablets",
                max_digits=20,
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
    ]
