# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_dx_review", "0003_alter_diagnosislocations_options_and_more"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="diagnosislocations",
            name="edc_dx_revi_name_a39b40_idx",
        ),
        migrations.RemoveIndex(
            model_name="reasonsfortesting",
            name="edc_dx_revi_name_0b2844_idx",
        ),
    ]
