# Generated by Django 5.0.1 on 2024-02-15 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_form_runners", "0002_alter_issue_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="issue",
            name="visit_code",
            field=models.CharField(max_length=25, null=True),
        ),
        migrations.AlterField(
            model_name="issue",
            name="visit_code_sequence",
            field=models.IntegerField(null=True),
        ),
    ]
