
<!-- begin results body -->
{% for result in results %}
    <tr>

    <td>{{ forloop.counter }}</td>

    {% include 'edc_dashboard/include/buttons_column.html' %}

    {% include 'edc_dashboard/include/columns.html' %}

    </tr>

{% endfor %}

<!-- begin results body -->
