from clinicedc_constants import (
    CANCELLED,
    CLOSED,
    HIGH_PRIORITY,
    LOW_PRIORITY,
    MEDIUM_PRIORITY,
    NEW,
    OPEN,
)

ACTION_STATUS = (
    (NEW, "New"),
    (OPEN, "Open"),
    (CLOSED, "Closed"),
    (CANCELLED, "Cancelled"),
)

PRIORITY = (
    (HIGH_PRIORITY, "High Priority"),
    (MEDIUM_PRIORITY, "Medium Priority"),
    (LOW_PRIORITY, "Low Priority"),
)
