# Generated by Django 5.2.10 on 2026-01-25 02:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0125_rename_repack_item_qty_historicalrepackrequest_item_qty_repack_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="item_qty_processed",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers processed",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="item_qty_processed",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers processed",
            ),
        ),
    ]
