ALLOCATED = "allocated"
ALREADY_CONFIRMED = "already_confirmed"
AVAILABLE = "available"
CANCELLED = "cancelled"
CENTRAL_LOCATION = "central"
CONTROL_ARM = "control_arm"
DAYS = "days"
DISPENSED = "dispensed"
FILLED = "filled"
INVALID = "invalid"
IN_PROGRESS_APPT = "in_progress"
NOT_STORED_AT_LOCATION = "not_stored_at_location"
PARTIAL = "partial"
PER_DAY = "day"
PER_HR = "hr"
PRESCRIPTION_ACTION = "prescription"
PRINT_SELECTED = "print_selected"
PROBLEM = "problem"
RECEIVE = "receive"
REPACK = "repack"
RESERVED = "reserved"
SINGLE = "single"
SOLUTION = "SOLUTION"
ZERO_ITEM = "zero_item"
