# Generated by Django 4.2.11 on 2024-06-19 01:07

import django.db.models.deletion
from django.db import migrations, models

import django.utils.timezone


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("edc_qareports", "0005_edcpermissions"),
    ]

    operations = [
        migrations.CreateModel(
            name="QaReportLog",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("username", models.CharField(max_length=100)),
                ("report_model", models.CharField(max_length=100)),
                ("accessed", models.DateTimeField(default=django.utils.timezone.now)),
                (
                    "site",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sites.site"
                    ),
                ),
            ],
            options={
                "verbose_name": "QA Report Log",
                "verbose_name_plural": "QA Report Logs",
            },
        ),
    ]
