{% extends 'edc_model_admin/admin/app_index.html' %}
{% load i18n admin_urls static admin_modify %}
{% load edc_dashboard_extras edc_admin_modify edc_navbar_extras %}

{% block branding %}
  {% show_navbar_for_admin_templates_b3 %} <a href="{% url "edc_adverse_event:home_url" %}">{{ opts.app_config.verbose_name|capfirst }}</a>
{% endblock %}
