# Generated by Django 5.1.2 on 2024-11-11 14:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pylabels", "0009_remove_labelconfiguration_requires_allocated_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="labelconfiguration",
            name="requires_allocation",
            field=models.BooleanField(
                default=False, verbose_name="Configuration is for a subject label"
            ),
        ),
    ]
