{% extends edc_base_template %}

{% load static %}

{% block main %}

 <div class="container">

    <div id="div-home-left" class="col-md-6">

          <div class="panel panel-default">
            <div class="panel-heading">Configuration</div>
                <div class="panel-body">
                  <table id="tbl-label-templates" class="table table-striped table_responsive">
                  <thead><th>Name</th><th>Value</th></thead>
                  <tr><td>ID</td><td>{{ app_config.device_id }}</td></tr>
                  <tr><td>Role</td><td>{{ app_config.role }}</td></tr>
                  <tr><td>IP Address</td><td>{{ ip_address }}</td></tr>
                  </table>
                </div>
          </div>

    </div><!--div-home-left -->

    <div id="div-home-right" class="col-md-6">
          <div class="panel panel-default">
            <div class="panel-heading">Environment</div>
                <div class="panel-body">
                  <table id="tbl-label-templates" class="table table-striped table_responsive">
                  <thead><th>Name</th><th>Value</th></thead>
                  <tr><td>Central Server</td><td>{{ app_config.central_server_id }}</td></tr>
                  <tr><td>Servers</td><td>{{ app_config.server_id_list|default:""|join:", " }}</td></tr>
                  <tr><td>Node Servers</td><td>{{ app_config.node_server_id_list|default:""|join:", " }}</td></tr>
                  <tr><td>"Middleman" devices</td><td>{{ app_config.middleman_id_list|default:""|join:", " }}</td></tr>
                  </table>
                </div>
          </div>


    </div><!--div-home-right -->

</div> <!-- container -->
{% endblock main %}
