# Generated by Django 3.0.6 on 2020-07-29 20:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0016_auto_20200327_1435"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="datadictionary",
            options={
                "default_permissions": ("view", "export"),
                "ordering": ("model", "number", "prompt"),
                "verbose_name": "Data Dictionary Item",
                "verbose_name_plural": "Data Dictionary Items",
            },
        ),
        migrations.AlterModelOptions(
            name="datamanageruser",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Data Manager User",
                "verbose_name_plural": "Data Manager Users",
            },
        ),
        migrations.AlterModelOptions(
            name="dataquery",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Data Query",
                "verbose_name_plural": "Data Queries",
            },
        ),
        migrations.AlterModelOptions(
            name="queryrule",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("title",),
                "verbose_name": "Query Rule",
                "verbose_name_plural": "Query Rules",
            },
        ),
        migrations.AlterModelOptions(
            name="querysubject",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Subject",
                "verbose_name_plural": "Subjects",
            },
        ),
        migrations.AlterModelOptions(
            name="queryuser",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Data Query User",
                "verbose_name_plural": "Data Query Users",
            },
        ),
        migrations.AlterModelOptions(
            name="queryvisitschedule",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Visit Schedule",
                "verbose_name_plural": "Visit Schedule",
            },
        ),
        migrations.AlterModelOptions(
            name="requisitionpanel",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Requisition Panel",
                "verbose_name_plural": "Requisition Panels",
            },
        ),
    ]
