# Generated by Django 6.0 on 2026-01-19 20:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0104_allocation_subject_identifier_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="allocation",
            name="code",
            field=models.CharField(
                blank=True,
                editable=False,
                help_text="A unique alphanumeric code",
                max_length=15,
                null=True,
                unique=True,
                verbose_name="Stock code",
            ),
        ),
        migrations.AddField(
            model_name="historicalallocation",
            name="code",
            field=models.CharField(
                blank=True,
                db_index=True,
                editable=False,
                help_text="A unique alphanumeric code",
                max_length=15,
                null=True,
                verbose_name="Stock code",
            ),
        ),
    ]
