# Generated by Django 5.2.10 on 2026-01-25 17:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0129_historicalrepackrequest_override_container_unit_qty_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstocktransfer",
            name="cancel",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Leave blank. Otherwise type 'CANCEL' to cancel this transfer.",
                max_length=15,
                verbose_name="To cancel this transfer, type 'CANCEL'",
            ),
        ),
        migrations.AddField(
            model_name="historicalstocktransfer",
            name="comment",
            field=models.TextField(blank=True, default="", max_length=255),
        ),
        migrations.AddField(
            model_name="stocktransfer",
            name="cancel",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Leave blank. Otherwise type 'CANCEL' to cancel this transfer.",
                max_length=15,
                verbose_name="To cancel this transfer, type 'CANCEL'",
            ),
        ),
        migrations.AddField(
            model_name="stocktransfer",
            name="comment",
            field=models.TextField(blank=True, default="", max_length=255),
        ),
    ]
