# Generated by Django 5.1.2 on 2024-11-17 20:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0037_remove_historicalstock_confirmed_at_site_by_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstocktransferconfirmation",
            name="transfer_confirmation_identifier",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="A sequential unique identifier set by the EDC",
                max_length=36,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="stocktransferconfirmation",
            name="transfer_confirmation_identifier",
            field=models.CharField(
                blank=True,
                help_text="A sequential unique identifier set by the EDC",
                max_length=36,
                null=True,
                unique=True,
            ),
        ),
    ]
