# Generated by Django 2.2.6 on 2019-10-22 03:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_notification", "0004_auto_20190305_0123")]

    operations = [
        migrations.AddField(
            model_name="notification",
            name="mailing_list_address",
            field=models.EmailField(
                blank=True,
                max_length=254,
                null=True,
                verbose_name="Mailing list address",
            ),
        )
    ]
