NOTIFICATION = "NOTIFICATION"
codenames = [
    "edc_notification.add_notification",
    "edc_notification.change_notification",
    "edc_notification.delete_notification",
    "edc_notification.view_notification",
]
