{% load i18n %}

{% translate "The repack process is done in four steps. First, fill in a request and save. Then, select the row and choose <i>process repack request</i> from the Actions menu. Print labels. Affix labels to new stock items. Lastly, choose <i>Confirm repacked and labeled stock</i> from the Action menu." %}
