# Generated by Django 6.0 on 2026-01-18 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0098_remove_historicalstock_returned_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstock",
            name="confirmed_at_location",
            field=models.BooleanField(
                default=False, help_text="See confirmeatlocationitem."
            ),
        ),
        migrations.AddField(
            model_name="stock",
            name="confirmed_at_location",
            field=models.BooleanField(
                default=False, help_text="See confirmeatlocationitem."
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="in_transit",
            field=models.BooleanField(
                default=False, help_text="See stocktransferitem."
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="in_transit",
            field=models.BooleanField(
                default=False, help_text="See stocktransferitem."
            ),
        ),
    ]
