# Generated by Django 6.0 on 2026-01-19 16:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0102_dispenseitem_code_historicaldispenseitem_code_and_more"),
    ]

    operations = []
