# Generated by Django 5.2.10 on 2026-01-24 16:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0111_alter_container_qty_default_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstock",
            name="container_qty",
            field=models.DecimalField(decimal_places=2, max_digits=20, null=True),
        ),
        migrations.AddField(
            model_name="stock",
            name="container_qty",
            field=models.DecimalField(decimal_places=2, max_digits=20, null=True),
        ),
    ]
