# Generated by Django 6.0 on 2026-01-17 18:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0097_auto_20260115_0020"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalstock",
            name="returned",
        ),
        migrations.RemoveField(
            model_name="stock",
            name="returned",
        ),
        migrations.AddField(
            model_name="historicalstock",
            name="destroyed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicalstock",
            name="dispensed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicalstock",
            name="in_transit",
            field=models.BooleanField(
                default=False,
                help_text="See stocktransferitem and confirmatlocationitem.",
            ),
        ),
        migrations.AddField(
            model_name="stock",
            name="destroyed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="stock",
            name="dispensed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="stock",
            name="in_transit",
            field=models.BooleanField(
                default=False,
                help_text="See stocktransferitem and confirmatlocationitem.",
            ),
        ),
    ]
