# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_facility", "0016_alter_healthfacility_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healthfacility",
            name="gps",
            field=models.CharField(
                blank=True,
                default="",
                help_text="copy and paste directly from google maps",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="healthfacility",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="healthfacility",
            name="title",
            field=models.CharField(blank=True, default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalhealthfacility",
            name="gps",
            field=models.CharField(
                blank=True,
                default="",
                help_text="copy and paste directly from google maps",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealthfacility",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalhealthfacility",
            name="title",
            field=models.CharField(blank=True, default="", max_length=150),
        ),
    ]
