{% if visit_code %}<span class="text text-default"><small><i class="fas fa-spinner fa-fw" aria-hidden="true" data-toggle="tooltip" title="Appointment {{ visit_code }} is currently in progress"></i> {{ visit_code }}</small></span>{% endif %}
