# Generated by Django 5.2.10 on 2026-01-25 02:21

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0123_remove_historicalrepackrequest_requested_qty_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="repack_item_qty",
            field=models.IntegerField(
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="Number of containers",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="repack_item_qty",
            field=models.IntegerField(
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="Number of containers",
            ),
        ),
    ]
