# Generated by Django 5.2.10 on 2026-01-25 04:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0127_historicalrepackrequest_unit_qty_processed_and_more"),
    ]

    operations = []
