# Generated by Django 2.2.2 on 2019-09-22 02:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_sites", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="siteprofile",
            name="title",
            field=models.CharField(max_length=250, null=True),
        )
    ]
