# Generated by Django 5.0 on 2024-01-24 18:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_action_item",
            "0035_alter_actionitem_options_alter_actiontype_options_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterField(
            model_name="actionitem",
            name="priority",
            field=models.CharField(
                blank=True,
                choices=[
                    ("high", "High Priority"),
                    ("medium", "Medium Priority"),
                    ("low", "Low Priority"),
                ],
                help_text="Leave blank to use default for this action type.",
                max_length=25,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="priority",
            field=models.CharField(
                choices=[
                    ("high", "High Priority"),
                    ("medium", "Medium Priority"),
                    ("low", "Low Priority"),
                ],
                default="high",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="priority",
            field=models.CharField(
                blank=True,
                choices=[
                    ("high", "High Priority"),
                    ("medium", "Medium Priority"),
                    ("low", "Low Priority"),
                ],
                help_text="Leave blank to use default for this action type.",
                max_length=25,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
