# Generated by Django 5.2.10 on 2026-01-25 04:01

import django.core.validators
from decimal import Decimal
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0126_alter_historicalrepackrequest_item_qty_processed_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrepackrequest",
            name="unit_qty_processed",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0.0"),
                help_text="Automatically calculated",
                max_digits=10,
                verbose_name="Unit quantity processed",
            ),
        ),
        migrations.AddField(
            model_name="repackrequest",
            name="unit_qty_processed",
            field=models.DecimalField(
                decimal_places=2,
                default=Decimal("0.0"),
                help_text="Automatically calculated",
                max_digits=10,
                verbose_name="Unit quantity processed",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="container_unit_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Leave blank for default.",
                max_digits=10,
                null=True,
                validators=[django.core.validators.MinValueValidator(Decimal("1.0"))],
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="item_qty_processed",
            field=models.IntegerField(
                default=0, verbose_name="Number of containers processed"
            ),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="item_qty_repack",
            field=models.IntegerField(
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="Number of containers to repack",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="container_unit_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Leave blank for default.",
                max_digits=10,
                null=True,
                validators=[django.core.validators.MinValueValidator(Decimal("1.0"))],
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="item_qty_processed",
            field=models.IntegerField(
                default=0, verbose_name="Number of containers processed"
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="item_qty_repack",
            field=models.IntegerField(
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="Number of containers to repack",
            ),
        ),
    ]
