# Generated by Django 6.0 on 2025-03-14 00:45

from django.db import migrations

import edc_pharmacy.models.stock.allocation


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0064_historicalstockrequest_start_datetime_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="AllocationProxy",
            fields=[],
            options={
                "verbose_name": "Allocation",
                "verbose_name_plural": "Allocation",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("edc_pharmacy.allocation",),
            managers=[
                ("objects", edc_pharmacy.models.stock.allocation.Manager()),
            ],
        ),
    ]
