# Generated by Django 5.2.10 on 2026-01-24 15:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0110_remove_container_qty_suggested_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="container",
            name="qty_default",
            field=models.DecimalField(
                decimal_places=2,
                help_text="May be adjusted at receiving. Default value for entry form",
                max_digits=10,
                null=True,
                verbose_name="Default qty",
            ),
        ),
        migrations.AlterField(
            model_name="container",
            name="qty_places",
            field=models.IntegerField(
                default=0, help_text="May NOT be adjusted at receiving"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcontainer",
            name="qty_default",
            field=models.DecimalField(
                decimal_places=2,
                help_text="May be adjusted at receiving. Default value for entry form",
                max_digits=10,
                null=True,
                verbose_name="Default qty",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcontainer",
            name="qty_places",
            field=models.IntegerField(
                default=0, help_text="May NOT be adjusted at receiving"
            ),
        ),
    ]
