# Generated by Django 5.2.10 on 2026-01-24 15:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0109_rename_qty_decimal_places_container_qty_suggested_places_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="container",
            old_name="qty_suggested",
            new_name="qty_default",
        ),
        migrations.RenameField(
            model_name="container",
            old_name="qty_suggested_places",
            new_name="qty_places",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty_suggested",
            new_name="qty_default",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty_suggested_places",
            new_name="qty_places",
        ),
    ]
