
    <a class="list-group-item" href="{% if wrapped %}{{ change_color|default:'success' }}{% else %}{{ add_color|default:'warning' }}{% endif %}">

        {% include 'edc_dashboard/controls/change_button.html' %}

    </a>
