codenames = [
    "edc_refusal.add_subjectrefusal",
    "edc_refusal.change_subjectrefusal",
    "edc_refusal.delete_subjectrefusal",
    "edc_refusal.view_historicalsubjectrefusal",
    "edc_refusal.view_subjectrefusal",
]
