{% load l10n %}
{% load tz %}
{% localtime on %}
    <span style="white-space: nowrap;">{{ report_datetime.date|localize }}</span>
    <BR>
    <span class="text text-muted small">{{ utc_date|timeuntil:report_datetime.date }} ago</span>
{% endlocaltime %}
