# Generated by Django 5.2.3 on 2025-06-27 13:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_export",
            "0019_alter_datarequest_site_alter_datarequesthistory_site_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="datarequesthistory",
            name="edc_export__exporte_ba8050_idx",
        ),
        migrations.RemoveIndex(
            model_name="exportreceipt",
            name="edc_export__timesta_6a2406_idx",
        ),
        migrations.RemoveIndex(
            model_name="filehistory",
            name="edc_export__sent_da_01059e_idx",
        ),
        migrations.RemoveIndex(
            model_name="uploadexportreceiptfile",
            name="edc_export__created_f54b3c_idx",
        ),
        migrations.AddIndex(
            model_name="datarequesthistory",
            index=models.Index(
                fields=["exported_datetime"], name="edc_export__exporte_d57cf7_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="exportreceipt",
            index=models.Index(fields=["timestamp"], name="edc_export__timesta_a855d0_idx"),
        ),
        migrations.AddIndex(
            model_name="filehistory",
            index=models.Index(
                fields=["sent_datetime"], name="edc_export__sent_da_10748e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="uploadexportreceiptfile",
            index=models.Index(fields=["created"], name="edc_export__created_bd7ff7_idx"),
        ),
    ]
