# Generated by Django 5.2.10 on 2026-01-24 15:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0106_auto_20260119_2332"),
    ]

    operations = [
        migrations.RenameField(
            model_name="container",
            old_name="qty",
            new_name="qty_suggested",
        ),
        migrations.RenameField(
            model_name="historicalcontainer",
            old_name="qty",
            new_name="qty_suggested",
        ),
        migrations.AddField(
            model_name="historicalreceiveitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of items in this/these container(s). If more than one container is received here, all containers have the same container quantity",
                max_digits=20,
                null=True,
                verbose_name="Container quantity",
            ),
        ),
        migrations.AddField(
            model_name="receiveitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of items in this/these container(s). If more than one container is received here, all containers have the same container quantity",
                max_digits=20,
                null=True,
                verbose_name="Container quantity",
            ),
        ),
    ]
