# Generated by Django 4.2.1 on 2023-07-07 19:32

from django.db import migrations

import edc_pharmacy.models.prescription.rx_refill
import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_pharmacy",
            "0017_alter_box_options_alter_dispensinghistory_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="rxrefill",
            managers=[
                ("objects", edc_pharmacy.models.prescription.rx_refill.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]
