{% if history_obj %}
  {% if offschedule_datetime %}
    <div class="panel-footer">
      <span class="text text-success">SUBJECT IS OFF SCHEDULE. You may still review the data collection schedule above.</span> <BR><small>Subject was taken off the <b>{{ visit_schedule.verbose_name }} {{ schedule.verbose_name }}</b> schedule on {{ offschedule_datetime|date:"SHORT_DATE_FORMAT" }}. See <a href="{{ href }}">{{ verbose_name }}</a></small>
    </div>
  {% else %}
    <div class="panel-footer">
      <small>Subject was put on this schedule on {{ onschedule_datetime|date:"SHORT_DATE_FORMAT" }}. To take off this schedule complete <a href="{{ href }}">{{ verbose_name }}</a>.</small>
    </div>
  {% endif %}
{% endif %}
