# Generated by Django 4.2.7 on 2023-12-05 19:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0031_alter_dataquery_visit_code_sequence_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="datadictionary",
            options={
                "default_permissions": ("view", "export"),
                "verbose_name": "Data Dictionary Item",
                "verbose_name_plural": "Data Dictionary Items",
            },
        ),
        migrations.AlterModelOptions(
            name="dataquery",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Data Query",
                "verbose_name_plural": "Data Queries",
            },
        ),
        migrations.AlterModelOptions(
            name="queryrule",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Query Rule",
                "verbose_name_plural": "Query Rules",
            },
        ),
    ]
