# Generated by Django 6.0.1 on 2026-01-29 19:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0133_auto_20260126_0216"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="storagebinproxy",
            options={
                "verbose_name": "Central Storage bin",
                "verbose_name_plural": "Central Storage bins",
            },
        ),
    ]
