# Generated by Django 5.2.10 on 2026-01-24 17:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0113_alter_historicalstock_container_qty_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalorderitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AddField(
            model_name="orderitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="unit_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280",
                max_digits=20,
                null=True,
                verbose_name="Total unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="container_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="unit_qty",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280",
                max_digits=20,
                null=True,
                verbose_name="Total unit quantity",
            ),
        ),
    ]
