# Generated by Django 5.2.10 on 2026-01-24 20:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0116_remove_historicalorderitem_qty_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalorderitem",
            name="container_unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="item_qty_ordered",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of containers",
                max_digits=20,
                null=True,
                verbose_name="Number of containers ordered",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="unit_qty_ordered",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Updated automatically (containers * unit_quantity per container)",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity ordered",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="unit_qty_pending",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Unit quantity ordered - Unit quantity received. Updated automatically",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity pending",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="unit_qty_received",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Updated automatically when units are received",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="item_qty_received",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers received",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="unit_qty_received",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="container_unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of units in the container(s). Must be the same for all containers in the record.",
                max_digits=20,
                null=True,
                verbose_name="Container unit quantity",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="item_qty_ordered",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of containers",
                max_digits=20,
                null=True,
                verbose_name="Number of containers ordered",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="unit_qty_ordered",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Updated automatically (containers * unit_quantity per container)",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity ordered",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="unit_qty_pending",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Unit quantity ordered - Unit quantity received. Updated automatically",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity pending",
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="unit_qty_received",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Updated automatically when units are received",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="item_qty_received",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers received",
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="unit_qty_received",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="number of containers x container unit qty, e.g. 10 x Bottle of 128 = 1280",
                max_digits=20,
                null=True,
                verbose_name="Unit quantity received",
            ),
        ),
    ]
