# Generated by Django 6.0.1 on 2026-01-21 22:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_appointment", "0051_alter_appointment_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="appointment",
            name="appt_timing",
            field=models.CharField(
                choices=[
                    ("ontime", "On time (within window period)"),
                    ("missed", "Missed"),
                    (
                        "extended",
                        "Extended (extended window period for final appointment)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="ontime",
                help_text="If late, you may also be required to complete a protocol incident report. Extended window period may be allowed for the final appointment. Refer to the protocol documentation for the allowed window periods of scheduled appointments.",
                max_length=25,
                verbose_name="Timing",
            ),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="appt_timing",
            field=models.CharField(
                choices=[
                    ("ontime", "On time (within window period)"),
                    ("missed", "Missed"),
                    (
                        "extended",
                        "Extended (extended window period for final appointment)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="ontime",
                help_text="If late, you may also be required to complete a protocol incident report. Extended window period may be allowed for the final appointment. Refer to the protocol documentation for the allowed window periods of scheduled appointments.",
                max_length=25,
                verbose_name="Timing",
            ),
        ),
    ]
