# Generated by Django 5.2.10 on 2026-01-25 23:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0131_storagebinitemproxy_storagebinproxy"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstoragebin",
            name="container",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_pharmacy.container",
            ),
        ),
        migrations.AddField(
            model_name="storagebin",
            name="container",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.container",
            ),
        ),
    ]
