# Generated by Django 6.0 on 2025-03-04 21:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0058_stockrequestproxy_alter_stockproxy_options"),
    ]

    operations = [
        migrations.DeleteModel(
            name="StockRequestProxy",
        ),
    ]
