# Generated by Django 5.2.10 on 2026-01-25 02:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0124_alter_historicalrepackrequest_repack_item_qty_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalrepackrequest",
            old_name="repack_item_qty",
            new_name="item_qty_repack",
        ),
        migrations.RenameField(
            model_name="repackrequest",
            old_name="repack_item_qty",
            new_name="item_qty_repack",
        ),
        migrations.RenameField(
            model_name="historicalrepackrequest",
            old_name="processed_qty",
            new_name="item_qty_processed",

        ),
        migrations.RenameField(
            model_name="repackrequest",
            old_name="processed_qty",
            new_name="item_qty_processed",

        ),
    ]
