# Generated by Django 3.0.6 on 2020-07-29 19:40

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_action_item", "0025_auto_20200528_0520"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="actionitem",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Action Item",
                "verbose_name_plural": "Action Items",
            },
        ),
        migrations.AlterModelOptions(
            name="actiontype",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ["name"],
            },
        ),
    ]
