# Generated by Django 5.1.2 on 2024-11-16 16:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0029_remove_historicalrepackrequest_qty_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalrepackrequest",
            name="processed",
        ),
        migrations.RemoveField(
            model_name="repackrequest",
            name="processed",
        ),
        migrations.AddField(
            model_name="historicalrepackrequest",
            name="processed_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers requested",
            ),
        ),
        migrations.AddField(
            model_name="repackrequest",
            name="processed_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Number of containers requested",
            ),
        ),
    ]
