from .constants import FILL_ACROSS

model_data = {
    "edc_lab.boxtype": [
        {
            "name": "9 x 9",
            "across": 9,
            "down": 9,
            "total": 81,
            "fill_order": FILL_ACROSS,
        }
    ]
}
