# Generated by Django 5.2.10 on 2026-01-24 19:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0114_historicalorderitem_container_qty_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalorderitem",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.RenameField(
            model_name="historicalreceiveitem",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.RenameField(
            model_name="historicalstock",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.RenameField(
            model_name="orderitem",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.RenameField(
            model_name="receiveitem",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.RenameField(
            model_name="stock",
            old_name="container_qty",
            new_name="container_unit_qty",
        ),
        migrations.AddField(
            model_name="container",
            name="qty_may_be_adjusted_from_default",
            field=models.BooleanField(
                default=False,
                verbose_name="Qty may be adjusted from the default on order / receive",
            ),
        ),
        migrations.AddField(
            model_name="historicalcontainer",
            name="qty_may_be_adjusted_from_default",
            field=models.BooleanField(
                default=False,
                verbose_name="Qty may be adjusted from the default on order / receive",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of containers",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalorderitem",
            name="unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="unit qty ordered less unit qty received. Updated in a signal",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="Number of containers",
                max_digits=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="unit_qty",
            field=models.DecimalField(
                decimal_places=2,
                help_text="unit qty ordered less unit qty received. Updated in a signal",
                max_digits=20,
                null=True,
            ),
        ),
    ]
