# Generated by Django 5.2.3 on 2025-07-01 03:17

from django.db import migrations, models

import django.utils.timezone


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0076_historicalstockadjustment_stockadjustment"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstockadjustment",
            name="adjustment_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name="stockadjustment",
            name="adjustment_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
