# Generated by Django 5.1 on 2024-08-14 18:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0013_rename_qareportnote_note_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="note",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Note",
                "verbose_name_plural": "Notes",
            },
        ),
        migrations.AlterField(
            model_name="note",
            name="status",
            field=models.CharField(
                choices=[
                    ("New", "New"),
                    ("PENDING", "Data is pending"),
                    ("closed", "Data not available"),
                ],
                default="New",
                max_length=25,
            ),
        ),
    ]
