# Generated by Django 5.2.10 on 2026-01-24 20:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0115_rename_container_qty_historicalorderitem_container_unit_qty_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalorderitem",
            old_name="qty",
            new_name="item_qty_ordered",
        ),
        migrations.RenameField(
            model_name="historicalorderitem",
            old_name="unit_qty",
            new_name="unit_qty_pending",
        ),
        migrations.RenameField(
            model_name="historicalreceiveitem",
            old_name="qty",
            new_name="item_qty_received",
        ),
        migrations.RenameField(
            model_name="historicalreceiveitem",
            old_name="unit_qty",
            new_name="unit_qty_received",
        ),
        migrations.RenameField(
            model_name="orderitem",
            old_name="qty",
            new_name="item_qty_ordered",
        ),
        migrations.RenameField(
            model_name="orderitem",
            old_name="unit_qty",
            new_name="unit_qty_pending",
        ),
        migrations.RenameField(
            model_name="receiveitem",
            old_name="qty",
            new_name="item_qty_received",
        ),
        migrations.RenameField(
            model_name="receiveitem",
            old_name="unit_qty",
            new_name="unit_qty_received",
        ),
    ]
