{% extends "edc_model_admin/admin/change_form.html" %}

{% load i18n admin_urls static admin_modify %}
{% load edc_dashboard_extras edc_admin_modify edc_navbar_extras %}

{% block branding %}
  {% show_navbar_for_admin_templates_b3 %}&nbsp;<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.app_config.verbose_name|capfirst }}</A>&nbsp;&rsaquo;&nbsp;{{ opts.verbose_name|capfirst }}
{% endblock %}
