# default group names

ACCOUNT_MANAGER = "ACCOUNT_MANAGER"
ADMINISTRATION = "ADMINISTRATION"
AUDITOR = "AUDITOR"
CELERY_MANAGER = "CELERY_MANAGER"
CLINIC = "CLINIC"
CLINIC_SUPER = "CLINIC_SUPER"
EVERYONE = "EVERYONE"
PII = "PII"
PII_VIEW = "PII_VIEW"

# default role names
ACCOUNT_MANAGER_ROLE = "account_manager"
AUDITOR_ROLE = "auditor"
CLINICIAN_ROLE = "clinician"
CLINICIAN_SUPER_ROLE = "clinician_super"
CUSTOM_ROLE = "custom"
NURSE_ROLE = "research_nurse"
STAFF_ROLE = "staff"
STATISTICIAN = "statistician"

# keys for the site_auths registry
UPDATE_ROLES_KEY = "update_roles"
UPDATE_GROUPS_KEY = "update_groups"
PRE_UPDATE_FUNCS_KEY = "pre_update_funcs"
POST_UPDATE_FUNCS_KEY = "post_update_funcs"
GROUPS_KEY = "groups"
ROLES_KEY = "roles"
PII_MODELS_KEY = "pii_models"
CUSTOM_PERMISSIONS_TUPLES_KEY = "custom_permissions_tuples"

TMG_ROLE = "tmg"
AE_ROLE = "ae_role"
