# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
import edc_model.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_lab", "0036_alter_aliquot_comment_alter_aliquot_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalorder",
            name="order_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                validators=[edc_model.validators.date.datetime_not_future],
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="order_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                validators=[edc_model.validators.date.datetime_not_future],
            ),
        ),
    ]
