# Generated by Django 5.2.6 on 2025-09-22 12:31

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_auth", "0035_alter_edcpermissions_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="alternate_email",
            field=models.EmailField(
                blank=True,
                default="",
                max_length=254,
                verbose_name="Alternate email address",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="clinic_label_printer",
            field=models.CharField(
                blank=True,
                default="",
                help_text='Change in <a href="/edc_label/">Edc Label Administration</a>',
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="export_format",
            field=models.CharField(
                blank=True,
                choices=[
                    ("CSV", "CSV (delimited by pipe `|`)"),
                    (114, "Stata v10 or later"),
                    (117, "Stata v13 or later"),
                    (118, "Stata v14 or later"),
                    (119, "Stata v15 or later"),
                ],
                default="CSV",
                help_text="Note: requires export permissions",
                max_length=25,
                verbose_name="Export format",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="job_title",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="lab_label_printer",
            field=models.CharField(
                blank=True,
                default="",
                help_text='Change in <a href="/edc_label/">Edc Label Administration</a>',
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="mobile",
            field=models.CharField(
                blank=True,
                default="",
                help_text="e.g. +1234567890",
                max_length=25,
                validators=[django.core.validators.RegexValidator(regex="^\\+\\d+")],
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="print_server",
            field=models.CharField(
                blank=True,
                default="",
                help_text='Change in <a href="/edc_label/">Edc Label Administration</a>',
                max_length=100,
            ),
        ),
    ]
