# Generated by Django 6.0 on 2026-01-14 21:20

from django.db import migrations
from django.db.migrations import RunPython
from tqdm import tqdm

from edc_pharmacy.models import StockTransferItem, StorageBinItem


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0096_auto_20260114_1800"),
    ]

    operations = []
